@@ -5,6 +5,7 @@ package Lingua::Translit;
 #   Alex Linke <alinke@lingua-systems.com>
 #   Rona Linke <rlinke@lingua-systems.com>
 # Copyright (C) 2009-2016 Lingua-Systems Software GmbH
+# Copyright (C) 2016 Netzum Sorglos, Lingua-Systems Software GmbH
 #
 
 use strict;
@@ -17,7 +18,7 @@ use Encode qw/encode decode/;
 
 use Lingua::Translit::Tables;
 
-our $VERSION = '0.25';
+our $VERSION = '0.26';
 
 =pod
 
@@ -50,7 +51,7 @@ writing system or alphabet to another one.
 The conversion is ideally unique, mapping one character to exactly one
 character, so the original spelling can be reconstructed.
 Practically this is not always the case and one single letter of the
-original alpabet can be transcribed as two, three or even more letters.
+original alphabet can be transcribed as two, three or even more letters.
 
 Furthermore there is more than one transliteration scheme for one writing
 system.
@@ -60,11 +61,11 @@ reconstruct the original data.
 
 Reconstruction is a problem though for non-unique transliterations, if no
 language specific knowledge is available as the resulting clusters of
-letters may be ambigous.
+letters may be ambiguous.
 For example, the Greek character "PSI" maps to "ps", but "ps" could also
 result from the sequence "PI", "SIGMA" since "PI" maps to "p" and "SIGMA"
 maps to s.
-If a transliteration table leads to ambigous conversions, the provided
+If a transliteration table leads to ambiguous conversions, the provided
 table cannot be used reverse.
 
 Otherwise the table can be used in both directions, if appreciated.
@@ -340,10 +341,8 @@ I<Devanagari IAST>, not reversible, Devanāgarī to IAST Romanization
 =head1 ADDING NEW TRANSLITERATIONS
 
 In case you want to add your own transliteration tables to
-L<Lingua::Translit>, have a look at the developer manual included in the
-distribution.
-An online version is available at
-L<http://www.lingua-systems.com/translit/downloads/>.
+L<Lingua::Translit>, have a look at the developer documentation at
+L<http://www.netzum-sorglos.de/software/lingua-translit/developer-documentation.html>.
 
 A template of a transliteration table is provided as well
 (F<xml/template.xml>) so you can easily start developing.
@@ -364,7 +363,8 @@ converted internally.
 
 None known.
 
-Please report bugs to perl@lingua-systems.com.
+Please report bugs using CPAN's request tracker at
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=Lingua-Translit>.
 
 =head1 SEE ALSO
 
@@ -372,7 +372,7 @@ L<Lingua::Translit::Tables>, L<Encode>, L<perlunicode>
 
 C<translit>'s manpage
 
-L<http://www.lingua-systems.com/translit/>
+L<http://www.netzum-sorglos.de/software/lingua-translit/>
 
 =head1 CREDITS
 
@@ -395,9 +395,9 @@ IAST" transliteration tables.
 
 =head1 AUTHORS
 
-Alex Linke <alinke@lingua-systems.com>
+Alex Linke <alinke@netzum-sorglos.de>
 
-Rona Linke <rlinke@lingua-systems.com>
+Rona Linke <rlinke@netzum-sorglos.de>
 
 =head1 LICENSE AND COPYRIGHT
 
@@ -405,6 +405,7 @@ Copyright (C) 2007-2008 Alex Linke and Rona Linke
 
 Copyright (C) 2009-2016 Lingua-Systems Software GmbH
 
+Copyright (C) 2016 Netzum Sorglos, Lingua-Systems Software GmbH
 
 This module is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
