@@ -5,6 +5,7 @@ package Lingua::Translit::Tables;
 #   Alex Linke <alinke@lingua-systems.com>
 #   Rona Linke <rlinke@lingua-systems.com>
 # Copyright (C) 2009-2016 Lingua-Systems Software GmbH
+# Copyright (C) 2016 Netzum Sorglos, Lingua-Systems Software GmbH
 #
 
 use strict;
@@ -13,7 +14,7 @@ use utf8;
 
 require 5.008;
 
-our $VERSION = '0.25';
+our $VERSION = '0.26';
 
 use Carp;
 
@@ -248,26 +249,24 @@ I<Devanagari IAST>, not reversible, Devanāgarī to IAST Romanization
 =head1 ADDING NEW TRANSLITERATIONS
 
 In case you want to add your own transliteration tables to
-L<Lingua::Translit>, have a look at the developer manual included in the
-distribution.
-An online version is available at
-L<http://www.lingua-systems.com/translit/downloads/>.
+L<Lingua::Translit>, have a look at the developer documentation at
+L<http://www.netzum-sorglos.de/software/lingua-translit/developer-documentation.html>.
 
 A template of a transliteration table is provided as well
 (F<xml/template.xml>) so you can easily start developing.
 
-
 =head1 BUGS
 
 None known.
 
-Please report bugs to perl@lingua-systems.com.
+Please report bugs using CPAN's request tracker at
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=Lingua-Translit>.
 
 =head1 SEE ALSO
 
 L<Lingua::Translit>
 
-L<http://www.lingua-systems.com/translit/>
+L<http://www.netzum-sorglos.de/software/lingua-translit/>
 
 
 =head1 CREDITS
@@ -291,9 +290,9 @@ IAST" transliteration tables.
 
 =head1 AUTHORS
 
-Alex Linke <alinke@lingua-systems.com>
+Alex Linke <alinke@netzum-sorglos.de>
 
-Rona Linke <rlinke@lingua-systems.com>
+Rona Linke <rlinke@netzum-sorglos.de>
 
 =head1 LICENSE AND COPYRIGHT
 
@@ -301,6 +300,8 @@ Copyright (C) 2007-2008 Alex Linke and Rona Linke
 
 Copyright (C) 2009-2016 Lingua-Systems Software GmbH
 
+Copyright (C) 2016 Netzum Sorglos, Lingua-Systems Software GmbH
+
 This module is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
